# Hedy

Hedy is a gradual programming language aimed at teaching programming and teaching Python. It teaches using different levels. The first level just offers printing text and asking for input. This level is meant to introduce learners to the idea of a programming language, and the environment. From there, Hedy builds up to include more complex syntax and additional concepts.

## Parts of Hedy

This repository contains the component that is the Hedy language, while <https://github.com/hedyorg/hedy> contains the website you see when you go to <https://hedy.org/>.

## Getting started

First, install [uv](https://docs.astral.sh/uv/getting-started/installation/), for example using Homebrew on macOS:

```
$ brew install uv
```

After cloning:

```
$ uv run doit test

# Or
$ uv run doit lark
$ uv run pytest
```

Releasing:

```
$ uv run doit publish
```

## Thanks to all Contributors

Thank you very much for taking your time to help Hedy.

[![Contributors](https://contrib.rocks/image?repo=hedyorg/hedy)]([https://github.com/codemaniac-sahil/news-webapp-api](https://github.com/hedyorg/hedy)https://github.com/hedyorg/hedy/graphs/contributors)
<p align="right">(<a href="#top">🔼 Back to top</a>)</p>
